pyina scripts documentation
===========================

ezpool script
-------------

.. automodule:: _ezpool
    :members:

ezscatter script
----------------

.. automodule:: _ezscatter
    :members:

mpi_world script
----------------

.. automodule:: _mpi_world
    :members:
    :exclude-members: launch, alias, set_master, set_workers, kill_all

